BFGraph: KmerHashTable< T, Hash >::iterator_< is_const_iterator > Class Template Reference

BFGraph

Public Types | Public Member Functions | Data Fields | Friends
KmerHashTable< T, Hash >::iterator_< is_const_iterator > Class Template Reference

Inherits iterator< std::forward_iterator_tag, value_type >.

## Public Types
typedef std::conditional< is_const_iterator, const KmerHashTable *, KmerHashTable * >::type | DataStructurePointerType
typedef std::conditional< is_const_iterator, const value_type &, value_type & >::type | ValueReferenceType
typedef std::conditional< is_const_iterator, const value_type *, value_type * >::type | ValuePointerType

## Public Member Functions
| iterator_ (DataStructurePointerType ht_)
| iterator_ (DataStructurePointerType ht_, size_t h_)
| iterator_ (const iterator_< false > &o)
iterator_ & | operator= (const iterator_ &o)
ValueReferenceType | operator* () const
ValuePointerType | operator-> () const
size_t | getHash () const
void | find_first ()
iterator_ | operator++ (int)
iterator_ & | operator++ ()
bool | operator== (const iterator_ &o) const
bool | operator!= (const iterator_ &o) const

## Data Fields
DataStructurePointerType | ht
size_t | h

## Friends
class | iterator_< true >

The documentation for this class was generated from the following file:

- src/KmerHashTable.h